contexttools.ClefMarkInventory
==============================

.. inheritance-diagram:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory
   :private-bases:

.. autoclass:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.name

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

Methods
-------

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.append

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.count

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.extend

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.index

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.insert

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.pop

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.remove

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.reverse

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.sort

    Inherited from :py:class:`__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__add__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__contains__

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__delitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__delslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__eq__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__ge__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__getitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__getslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__gt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__iadd__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__imul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__iter__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__le__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__len__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__lt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__mul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__ne__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__repr__

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__reversed__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__rmul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__setitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__setslice__

    Inherited from :py:class:`__builtin__.list`
